#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author:lei
@file:core.py
@time:2022/05/22
@邮箱：leigang431@163.com
"""

def lg():
    print("雷钢:一个乐观积极向上的人!")

def ywj():
    print("殷文俊:一个乐观积极向上的人!")

def lsc():
    print("李升晨:一个乐观积极向上的人!")

def pb():
    print("彭博:一个乐观积极向上的人!")

def cxy():
    print("陈星宇:一个乐观积极向上的人!")

def all():
    print("祝南5舍629的兄弟们前程似锦!")


#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author:lei
@file:setup.py.py
@time:2022/05/22
@邮箱：leigang431@163.com
"""
from setuptools import find_packages, setup

# Package meta-data.
NAME = 'nan5_629'
DESCRIPTION = '南5舍629的兄弟们 by leigang.'
URL = 'https://github.com/leigangblog'
EMAIL = 'leigang431@163.com'
AUTHOR = 'leigang'
REQUIRES_PYTHON = '>=3.6.0'
VERSION = '0.0.1'

# Setting.
setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(),
    license="MIT"
)